#
# spec file for package devilutionx
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2019-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           devilutionx
Version:        1.2.1
Release:        lp156.3.12
Summary:        An open source implementation of the Diablo 1 game engine
# 3rdParty/asio/* is licensed under BSL-1.0
# 3rdParty/libsmacker/* is licensed under CC-BY-NC-2.0 and CC-BY-SA-NC-2.0
# 3rdParty/[Storm|StormLib]/* is licensed under MIT
# 3rdParty/Radon/* is licensed under MIT
License:        SUSE-Public-Domain
Group:          Amusements/Games/RPG
URL:            https://github.com/diasurgical/devilutionX
#Git-Clone:     https://github.com/diasurgical/devilutionX.git
Source:         https://github.com/diasurgical/devilutionX/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source99:       baselibs.conf
BuildRequires:  cmake >= 3.13
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(SDL2_ttf)
BuildRequires:  pkgconfig(libsodium)
BuildRequires:  pkgconfig(sdl2)
# CharisSILB.ttf:
Requires:       sil-charis-fonts

%description
DevilutionX is a open source implementation of the game engine used
in Diablo1.
This package only includes the binary files, you still need the data
files from the original Diablo1 CD.

%prep
%setup -q -n devilutionX-%{version}

%build
export CXXFLAGS='%{optflags} -DTTF_FONT_PATH=\"/usr/share/fonts/truetype/CharisSILB.ttf\"'
%cmake \
  -DVERSION_NUM=%{version} \
  -DBINARY_RELEASE=ON
%make_jobs

%install
install -D -m 0755 build/devilutionx %{buildroot}%{_bindir}/devilutionx
install -p -D -m644 Packaging/resources/icon.png %{buildroot}%{_datadir}/icons/hicolor/512x512/apps/%{name}.png
%suse_update_desktop_file -c %{name} "DevilutionX" "A Diablo1 Game Engine" %{name} %{name} Game RolePlaying

%post
echo "copy diabdat.mpq to ~/.local/share/diasurgical/devilution/"

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/applications/%{name}.desktop

%changelog
* Tue Apr 13 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.1
  Gameplay
  * Gharbad not having to go out of vision before progressing his
    quest
  * Diablo: Items with negative AC morphing in multiplayer
  * Diablo: Griswold and Wirt selling unusually expensive items
  * Diablo: Gold not going directly to inventory
  * Hellfire: Some monsters having lower than intended HP
  * Hellfire: Auric Amulet not taking effect in most scenarios
  Stability / Performance / System
  * Quest panel crashing the game for some quests
  Bugfixes for original Hellfire bugs
  Gameplay
  * Rage/Search/Lightningwall not factoring in the hero level for
    the first player
  * Sparkling Shrine dealing an incorrect amount of damage
  * Items with negative AC morphing in multiplayer
* Tue Apr  6 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.0
  Gameplay
  * Hellfire support
  * Shareware support
  * Fully migrate saves between Diablo and Hellfire
  * Gold picked goes to stack even when inventory is open
  * Pepin automatically heals
  * Show other players on the map
  * Preserve list position when buying and selling items in stores
  * Preserve hotkeys and active spell across games
  * Set default active spell for new heroes
  * Experience bar (off by default)
  * Monster health bar (off by default)
  * Auto equip all item types on pickup or purchase (off by default)
  * Auto pickup gold (off by default)
  * Run in town (off by default) (also in multiplayer)
  * Disable friendly fire from arrows an spells (off by default)
  * Disable quest randomization (off by default)
  * Adria refills mana (off by default)
  * Barbarian and Bard heroes in Diablo (off by default)
  Controls
  * Use belt via the numpad
  * Close panels when pressing ESC
  * Shift-click to spend all stat points
  * Shift-click to clear readied spell
  * Shift-click consumables to move them between the belt and
    inventory
  * Shift-click equipment equip/unequip them
  * Controller mapping
  * D-Pad / Left stick navigation now works in all menus and is
    more responsive.
  * START + SELECT now opens the main menu.
  * Right stick mouse emulation has been improved.
  * Gamepads plugged in while the game is running can be used.
  * All connected gamepads can be used (previously, only the
    first one).
  Graphics / Audio
  * Widescreen menus
  * Scroll subtitles at the same speed as narration reader
  * Apply sound volume to videos
  * Improved transparency (on by default)
  * Auto-equip sounds (off by default)
  * Show monster type (off by default)
  * Disable walking sounds (off by default)
  Stability / Performance / System
  * Document ini-file options
  * Reorganize ini-file
  * Allow for up to 99 save games of each type
  * Much lower memory usage (now in line with the original)
  * Configurable network port
  * Performance improvements
  * DIABDAT.MPQ may now be upper case
  * Support for portable installs
  * Support file paths longer than 259 characters
  * Add --ttf-dir and --ttf-name to allow for specifying a
    different UI font
  Bugfixes for original Diablo bugs
  Gameplay
  * Base damage not being updated when leveling up
  * Player vision radius not updating properly before changing
    level
  * Tiles not properly being marked as out of visibility when
    walking
  * Scavengers/Gravediggers taking damage when eating on higher
    difficulties
  * Flash only dealing 10%% damage in some directions
  * Not getting XP for the first monster placed on a level
  * Not getting XP from monsters hit by golems
  * Monsters going inactive when fighting golems offscreen
  * Monsters with hiding ability fleeing in the wrong direction
    from golems
  * Fallen fleeing in the wrong direction
  * Monsters charge directions being biased for some angles
  * Monsters not being able to properly judge the location of
    firewalls
  * Some unique items morphing on a new game
  * Incorrectly seeing legit items as duplicates
  * Items being destroyed if held in cursor when entering dungeon
  * Being able to waste gold on red scrolls when not having room
    for them
  * Gaining mana from reading books despite wearing an item with
    corruption
  * Gold piles will be filled to their max, before starting a
    new one
  * Inconsistent repair prices caused by rounding errors
  * Arkaine's Valor brought from previous games breaking the game
    state
  * Several issues causing Arkaine's Valor to enter a broken state
  * Black Mushroom quest not resetting between games
  * Randomly being teleported from level 15 to Lazarus' chamber
  * Several bugs in Lazarus quest when re-entering the teleport
  * Town portals appearing on two levels when cast in a quest level
  Controls
  * Inconsistent mouse behavior when opening/closing various panels
  Graphics / Audio
  * Gold icons graphics are always correct
  * Arrows graphics not aligning with the move direction
  * Wrong death sound when monster/golem kills another monster
  * Lights not always following unique monsters
  * Lights added on map update not working (Arkaine's Valor, etc.)
  * Player light radius not readjusting when a player is knocked
    back
  * Loadscreen colors on entering the Poison Water quest
  * Lava pools sometimes having roof tiles in them
  * Doors sometimes missing in Halls of The Blind
  * Broken outline on some inventory items
  Stability / Performance / System
  * Fix more stability issues
  Bugfixes from Hellfire 1.00 - 1.01
  * Monster hitpoints overflowing in Nightmare/Hell difficulty
  * Gharbad the Weak not dropping his item when killed by a golem
  * Some stability issues
  Known issues
  * Save game difficaulity does not carry over from 1.1.0
* Sun Oct 11 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.1.0
  Features
  * Proper widescreen (and other aspects) support.
  * Select difficulty in single player (remembered in the save
    game).
  * Adjustable game speed in-game.
  * V-sync can now be disabled in the ini.
  * Better line drawing function used for the automap.
  * Support for loading custom Hell level maps.
  * Make all objects and monsters available to custom maps.
  * Added support for joining a game via hostname instead of IP
  Bugfixes
  * You can now enter and exit fullscreen also when the game is
    paused.
  Original Diablo bugs
  * Fix some monsters AC and to-hit values on Nightmare/Hell
    ending up as 0.
  * Fix player base block resetting to 0 after loading a save game.
  * Correctly render trees in front of the player.
  * Fully render sprites that are larger than the floor tiles.
  * Fix objects disappearing when walking on the opposite wall.
  * Dupping via belt has been fixed.
  * Correctly detect if the mouse is clicking the world or UI in
    some areas.
  * Minor typography corrections.
  * Corrected name of Chamber of Bones in automap.
  * Correctly align the inventory slots.
* Sun Oct 11 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.3
  Bugfixes
  * Fix keyboard input in the menu
* Sat Oct 10 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.2
  Features
  * Support for integer scaling.
  * Controller: Map Start + L1/R1 to char/inventory.
  * Added --save-dir to allow for specifying the save game folder.
  * Correctly scale the game on systems with a non-standard DPI
    setting.
  Bugfixes
  * Some cave levels were generated with an incorrect layout.
  * Firebolt mana cost is now correct.
  * Allow players to join Nightmare/Hell games without first
    creating a game.
  * Correctly load the full white color.
  * Correct navigation in the difficulty select screen.
  * The window can now be resized after exiting fullscreen mode.
  * Fix memory leak in audio code.
  * Fix hanging for 20 sec on the error screen.
* Thu May  7 2020 Martin Hauke <mardnh@gmx.de>
- Clarify licenses for used 3rdParty libraries
* Mon Mar  9 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.1
  Features
  * Toggle fullscreen at any point by hitting alt+enter (mouse grab
    can be disabled in diablo.ini)
  * Controller: B button closes the currently active panel.
  * Added a navigation menu for controllers
  * Focus on the exit item before quitting.
  * Minor performance improvements (save/load time and main menu).
  Bugfixes
  * Game crashing on systems that do not report monitor refresh
    rate.
  * Fixed belt not working correctly when holding shift on us
    keyboard layouts
  * Always keep track of the latest hero level when selecting
    difficulty.
  * Correct screenshot path
  * Turn the screen red for 200ms when taking screenshots.
  * Fix town load screen missing on the first load for 32bit systems.
  * Fix minor HOM issue at some houses in town.
  * Allow for space as text input
  * Fixed a couple of typos in error messages
  Original Diablo bugs
  * Fix belt not working correctly when holding shift on *non-*us
    keyboard layouts
  * Fix one more rare crash.
* Wed Jan  1 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.0
  Features
  * FPS no longer capped at 20hz; smoother mouse and transitions
  * Full-featured gamepad support
  * All movies can now be skipped via ESC
  * Implement --help, --version and --data-dir
  * Implement FPS counter (-f)
  * Force windowed mode with -x
  * Skip startup movies with -n
  * Implement scroll wheel navigation
  * Implement touch support
  * Load assets from the same folder as the mpq
  * Faster loading
  Bugfixes
  * Fixed random missing sounds
  * Fixed NPCs not talking about the right quest
  * Error messages implemented in GUI
  * Fixed having to restart the game between network sessions
  * Fixed game not working on Radeon on some GPUs
  * Fixed panel missing after minimizing game is upscaling is
    disabled
  * Fixed clicks in the left letterbox being incorrectly handled
  * Fixed end movie not looping
  Original Diablo bugs
  * Fixed a large number of rare stability issues from the
    original game
  * Correctly take open panels into account when casting spells
  * Fix sound some times being muted after Diablo dies
- Drop not longer needed patch:
  * devilutionx-fix-build.patch
* Wed Oct 23 2019 Martin Hauke <mardnh@gmx.de>
- Mention baselibs.conf in the spec file
* Sun Oct 20 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.0
  Features
  * Sound is now accurate to the original
  * All in-game issues fixed
  * Delete hero, inline dialogs and scrollbars are now implemented
  * Screenshots now have different names
  * Multiple simultaneous dialogs fixed
  * Memory leaks and crashes fixed
  * All keys are now mapped
  * UI text now has correct shadows
  * Much lower CPU usage
  Known issues
  * Error dialogs not implemented in main UI
  * The game must restart after hosting multiplayer
* Sun May 19 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.4.0
  * Fixed flickering mouse in caves
  * Included font for rendering credits and progress screen
  * Upscaling can be disabled in diablo.ini
  * Direct file access implemented (mods don't won't need to pack
    their files in an MPQ)
  * Music and speech memory leaks fixed
* Wed Mar 20 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.3.1
  * Fix dialog volume
  * Fix crash in town in multiplayer
  * Screenshot implemented
- Adjust required cmake version
* Tue Mar 19 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.2.0
  * Fully implemented audio (all issues from 0.1.0 fixed)
  * Fully implemented multiplayer
  * Gameplay is fully featured and plays like the original
  * Memory leaks fixed
  * Most known crashes have been fixed
* Sat Mar  2 2019 Martin Hauke <mardnh@gmx.de>
- Initial package, version 0.1.0
